@@ -1,6 +1,6 @@
 """
 Obserware
-Copyright (C) 2021 Akashdeep Dhar
+Copyright (C) 2021-2022 Akashdeep Dhar
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -56,18 +56,10 @@ def return_pernic_threaded_statistics():
             (
                 indx,
                 netifsat[indx].isup,
-                "%s/s"
-                % mmrysize.format(
-                    nxntioct[indx].bytes_recv - pvntioct[indx].bytes_recv
-                ),
-                "%s/s"
-                % mmrysize.format(
-                    nxntioct[indx].bytes_sent - pvntioct[indx].bytes_sent
-                ),
-                "%dPk/s"
-                % int(nxntioct[indx].packets_recv - pvntioct[indx].packets_recv),
-                "%dPk/s"
-                % int(nxntioct[indx].packets_sent - pvntioct[indx].packets_sent),
+                "%s/s" % mmrysize.format(nxntioct[indx].bytes_recv - pvntioct[indx].bytes_recv),
+                "%s/s" % mmrysize.format(nxntioct[indx].bytes_sent - pvntioct[indx].bytes_sent),
+                "%dPk/s" % int(nxntioct[indx].packets_recv - pvntioct[indx].packets_recv),
+                "%dPk/s" % int(nxntioct[indx].packets_sent - pvntioct[indx].packets_sent),
                 "%s" % mmrysize.format(nxntioct[indx].bytes_recv),
                 "%s" % mmrysize.format(nxntioct[indx].bytes_sent),
                 "%ldPk(s)" % nxntioct[indx].packets_recv,
