@@ -1,6 +1,6 @@
 """
 Obserware
-Copyright (C) 2021 Akashdeep Dhar
+Copyright (C) 2021-2022 Akashdeep Dhar
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -19,12 +19,10 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 from PyQt5 import QtGui
 from PyQt5.QtCore import QSize, QThread
-from PyQt5.QtWidgets import *
+from PyQt5.QtWidgets import QAbstractItemView, QDialog, QListWidgetItem
 
 from obserware import __version__
-from obserware.sources.readers.cputwind.provider import (
-    return_mainscreen_onetimed_statistics,
-)
+from obserware.sources.readers.cputwind.provider import return_mainscreen_onetimed_statistics
 from obserware.sources.screens.cputwind.interface import Ui_cputwind
 from obserware.sources.screens.cputwind.worker import Worker
 from obserware.sources.widgets.cputwdgt.operations import CPUTWdgt
