@@ -1,6 +1,6 @@
 """
 Obserware
-Copyright (C) 2021 Akashdeep Dhar
+Copyright (C) 2021-2022 Akashdeep Dhar
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,9 +21,7 @@ import time
 
 from PyQt5.QtCore import QObject, pyqtSignal, pyqtSlot
 
-from obserware.sources.readers.cyclwind.provider import (
-    return_mainscreen_threaded_statistics,
-)
+from obserware.sources.readers.cyclwind.provider import return_mainscreen_threaded_statistics
 
 
 class Worker(QObject):
