@@ -1,6 +1,6 @@
 """
 Obserware
-Copyright (C) 2021 Akashdeep Dhar
+Copyright (C) 2021-2022 Akashdeep Dhar
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,7 +23,13 @@ from PyQt5 import QtGui, QtWidgets
 from PyQt5.QtChart import QChart, QPieSeries
 from PyQt5.QtCore import QSize, QThread
 from PyQt5.QtGui import QPainter
-from PyQt5.QtWidgets import *
+from PyQt5.QtWidgets import (
+    QAbstractItemView,
+    QDesktopWidget,
+    QListWidgetItem,
+    QMainWindow,
+    QTableWidgetItem,
+)
 
 from obserware import __version__
 from obserware.sources.readers.mainwind.tab_information import (
@@ -32,18 +38,15 @@ from obserware.sources.readers.mainwind.tab_information import (
     return_obserware_information,
     return_software_information,
 )
-from obserware.sources.readers.mainwind.tab_performance import (
-    return_bottombar_onetimed_statistics,
-)
+from obserware.sources.readers.mainwind.tab_performance import return_bottombar_onetimed_statistics
 from obserware.sources.screens.cputwind.operations import CPUTWind
 from obserware.sources.screens.cyclwind.operations import CyclWind
-from obserware.sources.screens.lgptwind.operations import LgPtWind
 from obserware.sources.screens.mainwind.interface import Ui_mainwind
 from obserware.sources.screens.mainwind.worker import Worker
-from obserware.sources.screens.phptwind.operations import PhPtWind
 from obserware.sources.screens.procwind.operations import ProcWind
-from obserware.sources.screens.sostwind.operations import SoStWind
+from obserware.sources.widgets.lgptwdgt.operations import LgPtWdgt
 from obserware.sources.widgets.ntwkwdgt.operations import NtwkWdgt
+from obserware.sources.widgets.phptwdgt.operations import PhPtWdgt
 
 
 class MainWind(QMainWindow, Ui_mainwind):
@@ -53,9 +56,6 @@ class MainWind(QMainWindow, Ui_mainwind):
         self.setupUi(self)
         self.setWindowTitle(self.title)
         self.cputwind = CPUTWind(parent=self)
-        self.sostwind = SoStWind(parent=self)
-        self.phptwind = PhPtWind(parent=self)
-        self.lgptwind = LgPtWind(parent=self)
         self.cyclwind = CyclWind(parent=self)
         self.obj = Worker()
         self.thread = QThread()
@@ -73,16 +73,13 @@ class MainWind(QMainWindow, Ui_mainwind):
     def handle_elements(self):
         self.initialize_window_on_screen_center()
         self.ntwklist.setSelectionMode(QAbstractItemView.NoSelection)
+        self.phptlist.setSelectionMode(QAbstractItemView.NoSelection)
+        self.lgptlist.setSelectionMode(QAbstractItemView.NoSelection)
         self.cpudtmbt.clicked.connect(self.cyclwind.exec)
-        self.mmscexbt.clicked.connect(self.sostwind.exec)
-        self.swphexbt.clicked.connect(self.phptwind.exec)
-        self.swlgexbt.clicked.connect(self.lgptwind.exec)
         self.proctree.setSelectionBehavior(QAbstractItemView.SelectRows)
         self.proctree.verticalHeader().setVisible(False)
         self.proctree.setColumnWidth(0, 75)
-        self.proctree.horizontalHeader().setSectionResizeMode(
-            1, QtWidgets.QHeaderView.Stretch
-        )
+        self.proctree.horizontalHeader().setSectionResizeMode(1, QtWidgets.QHeaderView.Stretch)
         self.proctree.setColumnWidth(2, 75)
         self.proctree.setColumnWidth(3, 125)
         self.proctree.setColumnWidth(4, 75)
@@ -125,8 +122,8 @@ class MainWind(QMainWindow, Ui_mainwind):
         # Preparing CPU graph
         self.cpud_time_series.setHoleSize(0.60)
         self.cpud_donut_chart.setBackgroundBrush(QtGui.QColor("transparent"))
-        cpud_free_slice = self.cpud_time_series.append("Free", 0.0)
-        cpud_used_slice = self.cpud_time_series.append("Used", 0.0)
+        self.cpud_time_series.append("Free", 0.0)
+        self.cpud_time_series.append("Used", 0.0)
         self.cpud_donut_chart.legend().hide()
         self.cpud_donut_chart.addSeries(self.cpud_time_series)
         self.cpud_donut_chart.setAnimationOptions(QChart.SeriesAnimations)
@@ -136,9 +133,9 @@ class MainWind(QMainWindow, Ui_mainwind):
         # Preparing Memory graph
         self.memo_time_series.setHoleSize(0.60)
         self.memo_donut_chart.setBackgroundBrush(QtGui.QColor("transparent"))
-        memo_free_slice = self.memo_time_series.append("Free", 0.0)
-        memo_cach_slice = self.memo_time_series.append("Cached", 0.0)
-        memo_used_slice = self.memo_time_series.append("Used", 0.0)
+        self.memo_time_series.append("Free", 0.0)
+        self.memo_time_series.append("Cached", 0.0)
+        self.memo_time_series.append("Used", 0.0)
         self.memo_time_series.append("Free", 0.0)
         self.memo_time_series.append("Used", 0.0)
         self.memo_donut_chart.legend().hide()
@@ -150,8 +147,8 @@ class MainWind(QMainWindow, Ui_mainwind):
         # Preparing Swap graph
         self.swap_time_series.setHoleSize(0.60)
         self.swap_donut_chart.setBackgroundBrush(QtGui.QColor("transparent"))
-        swap_free_slice = self.swap_time_series.append("Free", 0.0)
-        swap_used_slice = self.swap_time_series.append("Used", 0.0)
+        self.swap_time_series.append("Free", 0.0)
+        self.swap_time_series.append("Used", 0.0)
         self.swap_time_series.append("Free", 0.0)
         self.swap_time_series.append("Used", 0.0)
         self.swap_donut_chart.legend().hide()
@@ -172,26 +169,14 @@ class MainWind(QMainWindow, Ui_mainwind):
         self.ntwkbtrt.setText(str(statdict["ntwkscreen"]["globrate"]["bytes"]["sent"]))
         self.ntwkbrdt.setText(str(statdict["ntwkscreen"]["mainscrn"]["bytes"]["recv"]))
         self.ntwkbtdt.setText(str(statdict["ntwkscreen"]["mainscrn"]["bytes"]["sent"]))
-        self.ntwkprrt.setText(
-            str(statdict["ntwkscreen"]["globrate"]["packets"]["recv"])
-        )
-        self.ntwkptrt.setText(
-            str(statdict["ntwkscreen"]["globrate"]["packets"]["sent"])
-        )
-        self.ntwkprdt.setText(
-            str(statdict["ntwkscreen"]["mainscrn"]["packets"]["recv"])
-        )
-        self.ntwkptdt.setText(
-            str(statdict["ntwkscreen"]["mainscrn"]["packets"]["sent"])
-        )
+        self.ntwkprrt.setText(str(statdict["ntwkscreen"]["globrate"]["packets"]["recv"]))
+        self.ntwkptrt.setText(str(statdict["ntwkscreen"]["globrate"]["packets"]["sent"]))
+        self.ntwkprdt.setText(str(statdict["ntwkscreen"]["mainscrn"]["packets"]["recv"]))
+        self.ntwkptdt.setText(str(statdict["ntwkscreen"]["mainscrn"]["packets"]["sent"]))
         self.ntwkertx.setText(str(statdict["ntwkscreen"]["mainscrn"]["errors"]["recv"]))
         self.ntwkettx.setText(str(statdict["ntwkscreen"]["mainscrn"]["errors"]["sent"]))
-        self.ntwkdrtx.setText(
-            str(statdict["ntwkscreen"]["mainscrn"]["dropped"]["recv"])
-        )
-        self.ntwkdttx.setText(
-            str(statdict["ntwkscreen"]["mainscrn"]["dropped"]["sent"])
-        )
+        self.ntwkdrtx.setText(str(statdict["ntwkscreen"]["mainscrn"]["dropped"]["recv"]))
+        self.ntwkdttx.setText(str(statdict["ntwkscreen"]["mainscrn"]["dropped"]["sent"]))
         self.ntwkqant.setText("%d NIC(s)" % len(statdict["ntwkscreen"]["pernicrt"]))
         self.ntwklist.clear()
         for indx in range(len(statdict["ntwkscreen"]["pernicrt"])):
@@ -214,16 +199,54 @@ class MainWind(QMainWindow, Ui_mainwind):
                 indxinfo[12],
                 indxinfo[13],
             )
-            listitem.setSizeHint(QSize(675, 125))
+            listitem.setSizeHint(QSize(685, 120))
             self.ntwklist.setItemWidget(listitem, wdgtitem)
             self.ntwklist.addItem(listitem)
+        # Refresh partitions statistics tab
+        self.partqant.setText("%d unit(s)" % statdict["partscreen"]["counters"]["partqant"])
+        self.partbrrt.setText(statdict["partscreen"]["counters"]["savebyte"])
+        self.partbrdt.setText(statdict["partscreen"]["counters"]["savetime"])
+        self.partbtrt.setText(statdict["partscreen"]["counters"]["loadbyte"])
+        self.partbtdt.setText(statdict["partscreen"]["counters"]["loadtime"])
+        self.partprrt.setText(str(statdict["partscreen"]["counters"]["saveqant"]))
+        self.partprdt.setText(str(statdict["partscreen"]["counters"]["savemgqt"]))
+        self.partptrt.setText(str(statdict["partscreen"]["counters"]["loadqant"]))
+        self.partptdt.setText(str(statdict["partscreen"]["counters"]["loadmgqt"]))
+        self.phptstlb.setText(
+            "<b>Physical partitions</b> (%d units)" % len(statdict["partscreen"]["phptdata"])
+        )
+        self.phptlist.clear()
+        for indx in range(len(statdict["partscreen"]["phptdata"])):
+            listitem = QListWidgetItem(self.phptlist)
+            indxinfo = statdict["partscreen"]["phptdata"][indx]
+            wdgtitem = PhPtWdgt(
+                self,
+                indxinfo["phptdevc"],
+                indxinfo["phptfutl"],
+                indxinfo["phptfsys"],
+            )
+            listitem.setSizeHint(QSize(325, 115))
+            self.phptlist.setItemWidget(listitem, wdgtitem)
+            self.phptlist.addItem(listitem)
+        self.lgptstlb.setText(
+            "<b>Logical partitions</b> (%d units)" % len(statdict["partscreen"]["lgptdata"])
+        )
+        self.lgptlist.clear()
+        for indx in range(len(statdict["partscreen"]["lgptdata"])):
+            listitem = QListWidgetItem(self.lgptlist)
+            indxinfo = statdict["partscreen"]["lgptdata"][indx]
+            wdgtitem = LgPtWdgt(
+                self,
+                indxinfo["lgptdevc"],
+                indxinfo["lgptfutl"],
+                indxinfo["lgptfsys"],
+            )
+            listitem.setSizeHint(QSize(325, 115))
+            self.lgptlist.setItemWidget(listitem, wdgtitem)
+            self.lgptlist.addItem(listitem)
         # Refresh statistics on graph slices
-        self.cpud_time_series.slices()[0].setValue(
-            100 - statdict["bottomstat"]["cpud_percent"]
-        )
-        self.cpud_time_series.slices()[1].setValue(
-            statdict["bottomstat"]["cpud_percent"]
-        )
+        self.cpud_time_series.slices()[0].setValue(100 - statdict["bottomstat"]["cpud_percent"])
+        self.cpud_time_series.slices()[1].setValue(statdict["bottomstat"]["cpud_percent"])
         self.memo_time_series.slices()[0].setValue(
             statdict["perfscreen"]["memo"]["percentage"]["free"]
         )
@@ -240,74 +263,30 @@ class MainWind(QMainWindow, Ui_mainwind):
             statdict["perfscreen"]["swap"]["percentage"]["used"]
         )
         # Refresh textual statistics on the performance tab screen - Memory
-        self.memouspc.setText(
-            "%2.1f%%" % statdict["perfscreen"]["memo"]["percentage"]["used"]
-        )
-        self.memoccpc.setText(
-            "%2.1f%%" % statdict["perfscreen"]["memo"]["percentage"]["cached"]
-        )
-        self.memofrpc.setText(
-            "%2.1f%%" % statdict["perfscreen"]["memo"]["percentage"]["free"]
-        )
-        self.memousnm.setText(
-            "%s" % str(statdict["perfscreen"]["memo"]["absolute"]["used"])
-        )
-        self.memoccnm.setText(
-            "%s" % str(statdict["perfscreen"]["memo"]["absolute"]["cached"])
-        )
-        self.memofrnm.setText(
-            "%s" % str(statdict["perfscreen"]["memo"]["absolute"]["free"])
-        )
-        self.memottnm.setText(
-            "%s" % str(statdict["perfscreen"]["memo"]["absolute"]["total"])
-        )
-        self.memoacnm.setText(
-            "%s" % str(statdict["perfscreen"]["memo"]["absolute"]["active"])
-        )
-        self.memobfnm.setText(
-            "%s" % str(statdict["perfscreen"]["memo"]["absolute"]["buffers"])
-        )
-        self.memoshnm.setText(
-            "%s" % str(statdict["perfscreen"]["memo"]["absolute"]["shared"])
-        )
-        self.memosbnm.setText(
-            "%s" % str(statdict["perfscreen"]["memo"]["absolute"]["slab"])
-        )
+        self.memouspc.setText("%2.1f%%" % statdict["perfscreen"]["memo"]["percentage"]["used"])
+        self.memoccpc.setText("%2.1f%%" % statdict["perfscreen"]["memo"]["percentage"]["cached"])
+        self.memofrpc.setText("%2.1f%%" % statdict["perfscreen"]["memo"]["percentage"]["free"])
+        self.memousnm.setText("%s" % str(statdict["perfscreen"]["memo"]["absolute"]["used"]))
+        self.memoccnm.setText("%s" % str(statdict["perfscreen"]["memo"]["absolute"]["cached"]))
+        self.memofrnm.setText("%s" % str(statdict["perfscreen"]["memo"]["absolute"]["free"]))
+        self.memottnm.setText("%s" % str(statdict["perfscreen"]["memo"]["absolute"]["total"]))
+        self.memoacnm.setText("%s" % str(statdict["perfscreen"]["memo"]["absolute"]["active"]))
+        self.memobfnm.setText("%s" % str(statdict["perfscreen"]["memo"]["absolute"]["buffers"]))
+        self.memoshnm.setText("%s" % str(statdict["perfscreen"]["memo"]["absolute"]["shared"]))
+        self.memosbnm.setText("%s" % str(statdict["perfscreen"]["memo"]["absolute"]["slab"]))
         # Refresh textual statistics on the performance tab screen - Swap
-        self.swapuspc.setText(
-            "%2.1f%%" % statdict["perfscreen"]["swap"]["percentage"]["used"]
-        )
-        self.swapfrpc.setText(
-            "%2.1f%%" % statdict["perfscreen"]["swap"]["percentage"]["free"]
-        )
-        self.swapusnm.setText(
-            "%s" % str(statdict["perfscreen"]["swap"]["absolute"]["used"])
-        )
-        self.swapfrnm.setText(
-            "%s" % str(statdict["perfscreen"]["swap"]["absolute"]["free"])
-        )
-        self.swapttnm.setText(
-            "%s" % str(statdict["perfscreen"]["swap"]["absolute"]["total"])
-        )
-        self.swapsinm.setText(
-            "%s" % str(statdict["perfscreen"]["swap"]["absolute"]["sin"])
-        )
-        self.swapsonm.setText(
-            "%s" % str(statdict["perfscreen"]["swap"]["absolute"]["sout"])
-        )
+        self.swapuspc.setText("%2.1f%%" % statdict["perfscreen"]["swap"]["percentage"]["used"])
+        self.swapfrpc.setText("%2.1f%%" % statdict["perfscreen"]["swap"]["percentage"]["free"])
+        self.swapusnm.setText("%s" % str(statdict["perfscreen"]["swap"]["absolute"]["used"]))
+        self.swapfrnm.setText("%s" % str(statdict["perfscreen"]["swap"]["absolute"]["free"]))
+        self.swapttnm.setText("%s" % str(statdict["perfscreen"]["swap"]["absolute"]["total"]))
+        self.swapsinm.setText("%s" % str(statdict["perfscreen"]["swap"]["absolute"]["sin"]))
+        self.swapsonm.setText("%s" % str(statdict["perfscreen"]["swap"]["absolute"]["sout"]))
         # Refresh textual statistics on the performance tab screen - CPU
-        self.cpudcsnm.setText(
-            str(statdict["perfscreen"]["cpud"]["absolute"]["ctx_switches"])
-        )
-        self.cpudinnm.setText(
-            str(statdict["perfscreen"]["cpud"]["absolute"]["interrupts"])
-        )
-        self.cpudsinm.setText(
-            str(statdict["perfscreen"]["cpud"]["absolute"]["soft_interrupts"])
-        )
-        self.cpudscnm.setText(
-            str(statdict["perfscreen"]["cpud"]["absolute"]["sys_calls"])
-        )
+        self.cpudcsnm.setText(str(statdict["perfscreen"]["cpud"]["absolute"]["ctx_switches"]))
+        self.cpudinnm.setText(str(statdict["perfscreen"]["cpud"]["absolute"]["interrupts"]))
+        self.cpudsinm.setText(str(statdict["perfscreen"]["cpud"]["absolute"]["soft_interrupts"]))
+        self.cpudscnm.setText(str(statdict["perfscreen"]["cpud"]["absolute"]["sys_calls"]))
         # Refresh process table on the processes tab screen
         self.procqant.setText("%d processes" % statdict["procscreen"]["process_count"])
         self.proctree.setRowCount(0)
