@@ -1,6 +1,6 @@
 """
 Obserware
-Copyright (C) 2021 Akashdeep Dhar
+Copyright (C) 2021-2022 Akashdeep Dhar
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
 
-from PyQt5.QtWidgets import *
+from PyQt5.QtWidgets import QWidget
 
 from obserware.sources.widgets.cputwdgt.interface import Ui_cputwdgt
 
@@ -112,24 +112,20 @@ class CPUTWdgt(QWidget, Ui_cputwdgt):
             % (secs_cputuspr, perc_cputuspr)
         )
         self.cputkrnm.setText(
-            "<b>Executing processes in kernel mode:</b> %s (%d%%)"
-            % (secs_cputkrnm, perc_cputkrnm)
+            "<b>Executing processes in kernel mode:</b> %s (%d%%)" % (secs_cputkrnm, perc_cputkrnm)
         )
         self.cputnull.setText(
-            "<b>Doing absolutely nothing:</b> %s (%d%%)"
-            % (secs_cputnull, perc_cputnull)
+            "<b>Doing absolutely nothing:</b> %s (%d%%)" % (secs_cputnull, perc_cputnull)
         )
         self.cputiowt.setText(
             "<b>Waiting for I/O operations to complete:</b> %s (%d%%)"
             % (secs_cputiowt, perc_cputiowt)
         )
         self.cputhirq.setText(
-            "<b>Servicing hardware interrupts:</b> %s (%d%%)"
-            % (secs_cputhirq, perc_cputhirq)
+            "<b>Servicing hardware interrupts:</b> %s (%d%%)" % (secs_cputhirq, perc_cputhirq)
         )
         self.cputsirq.setText(
-            "<b>Servicing software interrupts:</b> %s (%d%%)"
-            % (secs_cputsirq, perc_cputsirq)
+            "<b>Servicing software interrupts:</b> %s (%d%%)" % (secs_cputsirq, perc_cputsirq)
         )
         self.cputvirt.setText(
             "<b>Running other OSes in a virtualized environment:</b> %s (%d%%)"
@@ -178,24 +174,20 @@ class CPUTWdgt(QWidget, Ui_cputwdgt):
             % (secs_cputuspr, perc_cputuspr)
         )
         self.cputkrnm.setText(
-            "<b>Executing processes in kernel mode:</b> %s (%d%%)"
-            % (secs_cputkrnm, perc_cputkrnm)
+            "<b>Executing processes in kernel mode:</b> %s (%d%%)" % (secs_cputkrnm, perc_cputkrnm)
         )
         self.cputnull.setText(
-            "<b>Doing absolutely nothing:</b> %s (%d%%)"
-            % (secs_cputnull, perc_cputnull)
+            "<b>Doing absolutely nothing:</b> %s (%d%%)" % (secs_cputnull, perc_cputnull)
         )
         self.cputiowt.setText(
             "<b>Waiting for I/O operations to complete:</b> %s (%d%%)"
             % (secs_cputiowt, perc_cputiowt)
         )
         self.cputhirq.setText(
-            "<b>Servicing hardware interrupts:</b> %s (%d%%)"
-            % (secs_cputhirq, perc_cputhirq)
+            "<b>Servicing hardware interrupts:</b> %s (%d%%)" % (secs_cputhirq, perc_cputhirq)
         )
         self.cputsirq.setText(
-            "<b>Servicing software interrupts:</b> %s (%d%%)"
-            % (secs_cputsirq, perc_cputsirq)
+            "<b>Servicing software interrupts:</b> %s (%d%%)" % (secs_cputsirq, perc_cputsirq)
         )
         self.cputvirt.setText(
             "<b>Running other OSes in a virtualized environment:</b> %s (%d%%)"
