@@ -1,6 +1,6 @@
 """
 Obserware
-Copyright (C) 2021 Akashdeep Dhar
+Copyright (C) 2021-2022 Akashdeep Dhar
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,15 +20,13 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 from PyQt5 import QtGui
 from PyQt5.QtChart import QChart, QPieSeries
 from PyQt5.QtGui import QPainter
-from PyQt5.QtWidgets import *
+from PyQt5.QtWidgets import QWidget
 
 from obserware.sources.widgets.cyclwdgt.interface import Ui_cyclwdgt
 
 
 class CyclWdgt(QWidget, Ui_cyclwdgt):
-    def __init__(
-        self, parent=None, cyclnumb=0, cyclperc=0, cyclcurt=0, cyclxmin=0, cyclxmax=0
-    ):
+    def __init__(self, parent=None, cyclnumb=0, cyclperc=0, cyclcurt=0, cyclxmin=0, cyclxmax=0):
         super(CyclWdgt, self).__init__(parent)
         self.setupUi(self)
         self.cpuugraf = QChart()
