@@ -1,6 +1,6 @@
 """
 Obserware
-Copyright (C) 2021 Akashdeep Dhar
+Copyright (C) 2021-2022 Akashdeep Dhar
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
 
-from PyQt5 import QtGui
-from PyQt5.QtWidgets import *
+from PyQt5.QtWidgets import QWidget
 
 from obserware.sources.widgets.ntwkwdgt.interface import Ui_ntwkwdgt
 
@@ -82,15 +81,7 @@ class NtwkWdgt(QWidget, Ui_ntwkwdgt):
         self.ntwkstet.setText("toggle-on" if ntwkstet else "toggle-off")
         self.ntwkbrrt.setText("%s (%s)" % (ntwkbrrt, ntwkprrt))
         self.ntwkbtrt.setText("%s (%s)" % (ntwkbtrt, ntwkptrt))
-        self.ntwkbprx.setText(
-            "<b>%s</b> received (in <b>%s</b>)" % (ntwkbrxc, ntwkprxc)
-        )
-        self.ntwkbptx.setText(
-            "<b>%s</b> transmitted (in <b>%s</b>)" % (ntwkbtxc, ntwkptxc)
-        )
-        self.ntwkeprx.setText(
-            "<b>%s</b> faced (<b>%s</b> dropped)" % (ntwkefrx, ntwkpdrx)
-        )
-        self.ntwkeptx.setText(
-            "<b>%s</b> faced (<b>%s</b> dropped)" % (ntwkeftx, ntwkpdtx)
-        )
+        self.ntwkbprx.setText("<b>%s</b> received (in <b>%s</b>)" % (ntwkbrxc, ntwkprxc))
+        self.ntwkbptx.setText("<b>%s</b> transmitted (in <b>%s</b>)" % (ntwkbtxc, ntwkptxc))
+        self.ntwkeprx.setText("<b>%s</b> faced (<b>%s</b> dropped)" % (ntwkefrx, ntwkpdrx))
+        self.ntwkeptx.setText("<b>%s</b> faced (<b>%s</b> dropped)" % (ntwkeftx, ntwkpdtx))
